/*
 * Copyright (c) 2014 ISPRAS (www.ispras.ru)
 * 
 * Institute for System Programming of Russian Academy of Sciences
 * 
 * 25 Alexander Solzhenitsyn st. Moscow 109004 Russia
 * 
 * All rights reserved.
 * 
 * TestDataProviderBase.java, Oct 6, 2014 5:51:44 PM Andrei Tatarnikov
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase.stub;

import ru.ispras.testbase.TestBaseContext;
import ru.ispras.testbase.TestBaseQuery;
import ru.ispras.testbase.TestData;
import ru.ispras.testbase.TestDataProvider;
import ru.ispras.testbase.generator.DataGenerator;

import static ru.ispras.fortress.util.InvariantChecks.checkNotNull;

abstract class TdpBase implements DataGenerator {
  private final String name;

  public TdpBase(final String name) {
    checkNotNull(name);

    this.name = name;
  }

  public String getName() {
    return name;
  }

  @Override
  public final boolean isSuitable(final TestBaseQuery query) {
    return Utils.checkContextAttribute(query, TestBaseContext.TESTCASE, name);
  }

  @Override
  public final TestDataProvider generate(final TestBaseQuery query) {
    return TestDataProvider.singleton(generateData(query));
  }

  protected abstract TestData generateData(TestBaseQuery query);
}
